# AxiomX 0.0.73908 - the Dottie Number Edition

AxiomX is proud to release its second special edition release — the Dottie Number Edition. The Dottie number is actually defined as the root of the equation `cos x = x`. This edition contains the functions to calculate Dottie number and also we have introduced a new function.

## The Methods We've Added

* dottie_number() - Returns the exact value of the Dottie Number, i.e., 0.73908
* solve_equation(equation) - This method return the solution of the linear equation provided in a string in the form of `ax + b = c`.

## The constants we've added
* dottie - contains the exact value of the Dottie Number, calculated using the `dottie_number()` function.
* D - symbol for the Dottie Number.

## Version
`0.0.73908`

## Usage
```
import AxiomX as ax
print(ax.sin(ax.pi / 2))
```

## Notes

The `dottie_number()` method will be deprecated from the next release as it is only meant for this release only. However, the `dottie` and `D` constant will not be deprecated. This library is licensed under MIT and no one is supposed to copy code from AxiomX. Hope you enjoy AxiomX.